.. os-dpm documentation master file.

Welcome to os-dpm's documentation!
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

